@@ -43,6 +43,7 @@ class StateEngine(object):
         self.__delete_callback=None
         self.__change_callback=None
         self.__alarm_callback=None
+        self.__tether_callback=None
         self.__sock=socket.socket(socket.AF_INET)
         self.__nodes_loaded=False
         self.__sources_loaded=False
@@ -51,6 +52,8 @@ class StateEngine(object):
         self.__gpos_loaded=False
         self.__silences_loaded=False
         self.__clips_loaded=False
+        self.__tether_loaded=False
+        self.__tether_active=False
         self.__loaded=False
 
     def Destination(self,host_addr,slot):
@@ -131,6 +134,12 @@ class StateEngine(object):
         """
         return self.__gpos.values()
 
+    def isActive(self):
+        """
+           Return the tether state of the system.
+        """
+        return self.__tether_active
+
     def setPrivateObject(self,priv):
         """
         Set the object to be passed to callbacks in the 'priv' parameter.
@@ -226,6 +235,20 @@ class StateEngine(object):
      """
      self.__alarm_callback=cb
 
+    def setTetherCallback(self,cb):
+     """
+        Set the 'tether' callback, called by StateEngine immediately after
+        reception of change of state in the Tether system.
+
+           def callback(self,engine,priv,state)
+
+        where:
+             engine: reference to the calling StateEngine
+
+              state: Boolean containing the Tether state
+     """
+     self.__tether_callback=cb
+
     def clearCrosspoint(self,out_host_addr,out_slot):
         """
            Clear the multicast source address ("ADDR" attribute) of an
@@ -378,7 +401,7 @@ class StateEngine(object):
         return host_addr+":"+str(slot)
 
     def __processMessage(self):
-#       print self.__accum
+        #print(self.__accum)
         cmds=self.__accum.split("\t")
         if cmds[0]=="NODEADD":
             self.__nodes[cmds[1]]=Drouter.Node.Node(cmds)
@@ -469,6 +492,12 @@ class StateEngine(object):
                 self.__alarm_callback(self,self.__callback_priv,Drouter.Alarm.Alarm(cmds))
             return
 
+        if cmds[0]=="TETHER":
+            self.__tether_active=cmds[1]=='Y'
+            if (self.__tether_callback!=None) and self.__loaded:
+                self.__tether_callback(self,self.__callback_priv,cmds[1]=='Y')
+            return
+
         if cmds[0]=="ok":
             if not self.__nodes_loaded:
                 self.__nodes_loaded=True
@@ -498,9 +527,15 @@ class StateEngine(object):
             if not self.__silences_loaded:
                 self.__silences_loaded=True
                 self.__sock.send("SubscribeClips\r\n".encode('latin-1'))
+                return
 
             if not self.__clips_loaded:
                 self.__clips_loaded=True
+                self.__sock.send("SubscribeTether\r\n".encode('latin-1'))
+                return
+
+            if not self.__tether_loaded:
+                self.__tether_loaded=True
                 self.__loaded=True
                 if self.__ready_callback!=None:
                     self.__ready_callback(self,self.__callback_priv)
