@@ -26,6 +26,7 @@
 SaParser::SaParser(QObject *parent)
   : QObject(parent)
 {
+  sa_connected=false;
   sa_reading_routers=false;
   sa_reading_sources=false;
   sa_reading_dests=false;
@@ -40,6 +41,13 @@ SaParser::SaParser(QObject *parent)
   //
   sa_socket=NULL;
 
+  //
+  // Startup Timer
+  //
+  sa_startup_timer=new QTimer(this);
+  sa_startup_timer->setSingleShot(true);
+  connect(sa_startup_timer,SIGNAL(timeout()),this,SLOT(startupData()));
+
   //
   // Watchdog Timers
   //
@@ -61,6 +69,18 @@ QMap<int,QString> SaParser::routers() const
 }
 
 
+bool SaParser::isConnected() const
+{
+  return sa_connected;
+}
+
+
+bool SaParser::gpioSupported(int router) const
+{
+  return sa_gpio_supporteds.value(router);
+}
+
+
 int SaParser::inputQuantity(int router) const
 {
   return sa_input_names[router].size();
@@ -115,6 +135,44 @@ void SaParser::setOutputCrosspoint(int router,int output,int input)
 }
 
 
+QString SaParser::gpiState(int router,int input) const
+{
+  return sa_gpi_states[router][input];
+}
+
+
+void SaParser::setGpiState(int router,int input,const QString &code,int msec)
+{
+  if(msec<0) {
+    SendCommand(QString().sprintf("TriggerGPI %d %d %s",router,input,
+				  code.toUtf8().constData()));
+  }
+  else {
+    SendCommand(QString().sprintf("TriggerGPI %d %d %s %d",router,input,
+				  code.toUtf8().constData(),msec));
+  }
+}
+
+
+QString SaParser::gpoState(int router,int output) const
+{
+  return sa_gpo_states[router][output];
+}
+
+
+void SaParser::setGpoState(int router,int output,const QString &code,int msec)
+{
+  if(msec<0) {
+    SendCommand(QString().sprintf("TriggerGPO %d %d %s",router,output,
+				  code.toUtf8().constData()));
+  }
+  else {
+    SendCommand(QString().sprintf("TriggerGPO %d %d %s %d",router,output,
+				  code.toUtf8().constData(),msec));
+  }
+}
+
+
 int SaParser::snapshotQuantity(int router) const
 {
   return sa_snapshot_names[router].size();
@@ -175,11 +233,20 @@ void SaParser::connectedData()
 
 void SaParser::connectionClosedData()
 {
+  sa_connected=false;
+  Clear();
   emit connected(false,SaParser::WatchdogActive);
   sa_holdoff_timer->start(SAPARSER_HOLDOFF_INTERVAL);
 }
 
 
+void SaParser::startupData()
+{
+  sa_connected=true;
+  emit connected(true,SaParser::Ok);
+}
+
+
 void SaParser::holdoffReconnectData()
 {
   MakeSocket();
@@ -222,6 +289,23 @@ void SaParser::errorData(QAbstractSocket::SocketError err)
 }
 
 
+void SaParser::Clear()
+{
+  sa_router_names.clear();
+  sa_input_node_names.clear();
+  sa_input_names.clear();
+  sa_input_long_names.clear();
+  sa_output_node_names.clear();
+  sa_output_names.clear();
+  sa_output_long_names.clear();
+  sa_output_xpoints.clear();
+  sa_gpi_states.clear();
+  sa_gpo_states.clear();
+  sa_gpio_supporteds.clear();
+  sa_snapshot_names.clear();
+}
+
+
 void SaParser::DispatchCommand(QString cmd)
 {
   //printf("RECV: %s\n",(const char *)cmd.toUtf8());
@@ -240,6 +324,8 @@ void SaParser::DispatchCommand(QString cmd)
     else {
       sa_socket->deleteLater();
       sa_socket=NULL;
+      sa_connected=false;
+      Clear();
       emit connected(false,SaParser::InvalidLogin);
     }
     return;
@@ -360,13 +446,48 @@ void SaParser::DispatchCommand(QString cmd)
 	  if((router==sa_last_xpoint_router)&&(output==sa_last_xpoint_output)) {
 	    sa_last_xpoint_router=-1;
 	    sa_last_xpoint_output=-1;
-	    emit connected(true,SaParser::Ok);
+
+	    for(QMap<int,QString>::const_iterator it=sa_router_names.begin();
+		it!=sa_router_names.end();it++) {
+	      SendCommand(QString().sprintf("GPIStat %d",it.key()));
+	      SendCommand(QString().sprintf("GPOStat %d",it.key()));
+	    }
+	    sa_startup_timer->start(SAPARSER_STARTUP_INTERVAL);
 	  }
 	}
       }
     }
   }
 
+  //
+  // Process GPI State Changes
+  //
+  if((f0[0]=="gpistat")&&(f0.size()==4)) {
+    int router=f0[1].toUInt(&ok);
+    sa_gpio_supporteds[router]=true;
+    if(ok) {
+      int input=f0[2].toInt(&ok);
+      if(ok) {
+	sa_gpi_states[router][input]=f0[3];
+	emit gpiStateChanged(router,input,f0[3]);
+      }
+    }
+  }
+
+  //
+  // Process GPO State Changes
+  //
+  if((f0[0]=="gpostat")&&(f0.size()==4)) {
+    int router=f0[1].toUInt(&ok);
+    if(ok) {
+      int output=f0[2].toInt(&ok);
+      if(ok) {
+	sa_gpo_states[router][output]=f0[3];
+	emit gpoStateChanged(router,output,f0[3]);
+      }
+    }
+  }
+
   //  printf("CMD: %s\n",(const char *)cmd.toUtf8());
 }
 
