@@ -34,6 +34,7 @@
 #include <QTcpSocket>
 #include <QTimer>
 
+#define SAPARSER_STARTUP_INTERVAL 1000
 #define SAPARSER_HOLDOFF_INTERVAL 5000
 
 class SaParser : public QObject
@@ -44,6 +45,8 @@ class SaParser : public QObject
   SaParser(QObject *parent=0);
   ~SaParser();
   QMap<int,QString> routers() const;
+  bool isConnected() const;
+  bool gpioSupported(int router) const;
   int inputQuantity(int router) const;
   QString inputNodeName(int router,int input) const;
   QString inputName(int router,int input) const;
@@ -53,6 +56,10 @@ class SaParser : public QObject
   QString outputLongName(int router,int output) const;
   int outputCrosspoint(int router,int output) const;
   void setOutputCrosspoint(int router,int output,int input);
+  QString gpiState(int router,int input) const;
+  void setGpiState(int router,int input,const QString &code,int msec=-1);
+  QString gpoState(int router,int output) const;
+  void setGpoState(int router,int output,const QString &code,int msec=-1);
   int snapshotQuantity(int router) const;
   QString snapshotName(int router,int n) const;
   void activateSnapshot(int router,const QString &snapshot);
@@ -67,15 +74,19 @@ class SaParser : public QObject
   void inputListChanged();
   void outputListChanged();
   void outputCrosspointChanged(int router,int output,int input);
+  void gpiStateChanged(int router,int input,const QString &code);
+  void gpoStateChanged(int router,int output,const QString &code);
 
  private slots:
   void connectedData();
   void connectionClosedData();
+  void startupData();
   void holdoffReconnectData();
   void readyReadData();
   void errorData(QAbstractSocket::SocketError err);
 
  private:
+  void Clear();
   void DispatchCommand(QString cmd);
   void ReadRouterName(const QString &cmd);
   void ReadSourceName(const QString &cmd);
@@ -90,6 +101,7 @@ class SaParser : public QObject
   uint16_t sa_port;
   QString sa_username;
   QString sa_password;
+  bool sa_connected;
   QString sa_accum;
   bool sa_reading_routers;
   bool sa_reading_sources;
@@ -108,7 +120,11 @@ class SaParser : public QObject
   QMap<int,QMap<int,QString> > sa_output_names;
   QMap<int,QMap<int,QString> > sa_output_long_names;
   QMap<int,QMap<int,int> > sa_output_xpoints;
+  QMap<int,QMap<int,QString> > sa_gpi_states;
+  QMap<int,QMap<int,QString> > sa_gpo_states;
+  QMap<int,bool> sa_gpio_supporteds;
   QMap<int,QStringList> sa_snapshot_names;
+  QTimer *sa_startup_timer;
   QTimer *sa_holdoff_timer;
 };
 
