@@ -45,6 +45,7 @@ DRouter::DRouter(int *proto_socks,QObject *parent)
   : QObject(parent)
 {
   drouter_proto_socks=proto_socks;
+  drouter_writeable=false;
 
   drouter_config=new Config();
   drouter_config->load();
@@ -201,6 +202,56 @@ bool DRouter::start(QString *err_msg)
 }
 
 
+bool DRouter::isWriteable() const
+{
+  return drouter_writeable;
+}
+
+
+void DRouter::setWriteable(bool state)
+{
+  QString code;
+  QString sql;
+  QSqlQuery *q;
+  SyLwrpClient *lwrp=NULL;
+
+  if(drouter_writeable!=state) {
+    //
+    // Update Livewire GPIO
+    //
+    if((lwrp=drouter_nodes.value(drouter_config->tetherGpioIpAddress(Config::This).toIPv4Address()))!=NULL) {
+      code=drouter_config->tetherGpioCode(Config::This);
+      if(!state) {
+	code=SyGpioBundle::invertCode(code);
+      }
+      printf("Sending %s\n",(const char *)code.toUtf8());
+      lwrp->setGpiCode(drouter_config->tetherGpioSlot(Config::This),code);
+    }
+    if((lwrp=drouter_nodes.value(drouter_config->tetherGpioIpAddress(Config::That).toIPv4Address()))!=NULL) {
+      if(state) {
+	code=SyGpioBundle::invertCode(drouter_config->
+				      tetherGpioCode(Config::That));
+	lwrp->setGpiCode(drouter_config->tetherGpioSlot(Config::That),code);
+      }
+    }
+    qApp->processEvents();
+
+    //
+    // Update Protocols
+    //
+    QString letter="N";
+    if(state) {
+      letter="Y";
+    }
+    sql=QString("update TETHER set IS_ACTIVE='"+letter+"'");
+    q=new QSqlQuery(sql);
+    delete q;
+    drouter_writeable=state;
+    NotifyProtocols("TETHER",letter);
+  }
+}
+
+
 void DRouter::nodeConnectedData(unsigned id,bool state)
 {
   QString sql;
@@ -870,7 +921,16 @@ bool DRouter::ProcessIpcCommand(int sock,const QString &cmd)
     return false;
   }
 
+  //
+  // All operations below here require that we be the active instance!
+  // (drouter_writeable==true)
+  //
+  if(!drouter_writeable) {
+    return true;
+  }
+
   QStringList cmds=cmd.split(" ");
+
   if((cmds.at(0)=="ClearCrosspoint")&&(cmds.size()==3)) {
     SyLwrpClient *lwrp=drouter_nodes[QHostAddress(cmds.at(1)).toIPv4Address()];
     unsigned slotnum=cmds.at(2).toUInt(&ok);
@@ -1110,6 +1170,15 @@ bool DRouter::StartDb(QString *err_msg)
   q=new QSqlQuery(sql);
   delete q;
 
+  sql=QString("create table if not exists TETHER (")+
+    "IS_ACTIVE enum('N','Y') not null default 'N') "+
+    "engine MEMORY character set utf8 collate utf8_general_ci";
+  q=new QSqlQuery(sql);
+  delete q;
+  sql=QString("insert into TETHER set IS_ACTIVE='N'");
+  q=new QSqlQuery(sql);
+  delete q;
+
   return true;
 }
 
